@extends('adminlte::auth.auth-page', ['auth_type' => 'register'])

@php( $login_url = View::getSection('login_url') ?? config('adminlte.login_url', 'login') )
@php( $register_url = View::getSection('register_url') ?? config('adminlte.register_url', 'register') )

@if (config('adminlte.use_route_url', false))
    @php( $login_url = $login_url ? route($login_url) : '' )
    @php( $register_url = $register_url ? route($register_url) : '' )
@else
    @php( $login_url = $login_url ? url($login_url) : '' )
    @php( $register_url = $register_url ? url($register_url) : '' )
@endif

@section('auth_header', __('adminlte::adminlte.register_message'))

@section('auth_body')

        <form action="{{ $register_url }}" method="post">
                    {{ csrf_field() }}

                    {{-- Name field --}}


                    <div class="input-group mb-3">
                        <div class="form-group clearfix">
                          <div class="icheck-primary d-inline">
                            <input type="radio" id="pj" name="type" value="0" @if(old('type') == 0) checked="checked" @endif >
                            <label for="pj">
                              Pessoa Jurídica
                            </label>
                          </div>
                          <div class="icheck-primary d-inline" style="margin-left:15px;">
                            <input type="radio" id="pf" name="type" value="1" @if(old('type') == 1) checked="checked" @endif>
                            <label for="pf">
                              Pessoa Física
                            </label>
                          </div>
                        </div>
                    </div>

                   

                    <div class="form-group mb-3 pj @if(old('type') == 1) none @endif">
                        <input type="text" name="razao" class="form-control {{ $errors->has('razao') ? 'is-invalid' : '' }}"
                               value="{{ old('razao') }}" placeholder="{{ __('adminlte::adminlte.razao') }}" autocomplete="off" autofocus>
                        
                        @if($errors->has('razao'))
                            <div class="invalid-feedback">
                                <strong>{{ $errors->first('razao') }}</strong>
                            </div>
                        @endif
                    </div>

                    <div class="form-group mb-3 pf @if(old('type') == 0) none @endif">
                        <input type="text" name="name" class="form-control {{ $errors->has('name') ? 'is-invalid' : '' }}"
                               value="{{ old('name') }}" placeholder="{{ __('adminlte::adminlte.name') }}" autocomplete="off" autofocus>
                        
                        @if($errors->has('name'))
                            <div class="invalid-feedback">
                                <strong>{{ $errors->first('name') }}</strong>
                            </div>
                        @endif
                    </div>

                    <div class="form-group mb-3 pj @if(old('type') == 1) none @endif">
                        <input type="text" name="fantasy_name" class="form-control {{ $errors->has('fantasy_name') ? 'is-invalid' : '' }}"
                               value="{{ old('fantasy_name') }}" placeholder="{{ __('adminlte::adminlte.fantasy_name') }}" autocomplete="off">
                        
                        @if($errors->has('fantasy_name'))
                            <div class="invalid-feedback">
                                <strong>{{ $errors->first('fantasy_name') }}</strong>
                            </div>
                        @endif
                    </div>

                    <div class="form-group mb-3 pj @if(old('type') == 1) none @endif ">
                        <input type="text" name="cnpj" class="form-control cnpj {{ $errors->has('cnpj') ? 'is-invalid' : '' }}"
                               value="{{ old('cnpj') }}" placeholder="{{ __('adminlte::adminlte.cnpj') }}" autocomplete="off">
                        
                        @if($errors->has('cnpj'))
                            <div class="invalid-feedback">
                                <strong>{{ $errors->first('cnpj') }}</strong>
                            </div>
                        @endif
                    </div>

                    <div class="form-group mb-3 pf @if(old('type') == 0) none @endif" >
                        <input type="text" name="cpf" class="form-control cpf {{ $errors->has('cpf') ? 'is-invalid' : '' }}"
                               value="{{ old('cpf') }}" placeholder="{{ __('adminlte::adminlte.cpf') }}" autocomplete="off">
                        
                        @if($errors->has('cpf'))
                            <div class="invalid-feedback">
                                <strong>{{ $errors->first('cpf') }}</strong>
                            </div>
                        @endif
                    </div>

                    <div class="input-group mb-3">
                        <input type="text" name="address" class="form-control {{ $errors->has('address') ? 'is-invalid' : '' }}"
                               value="{{ old('address') }}" placeholder="{{ __('adminlte::adminlte.address') }}"  required autocomplete="off">
                        <div class="input-group-append">
                            <div class="input-group-text">
                                <span class="fas fa-map-marker {{ config('adminlte.classes_auth_icon', '') }}"></span>
                            </div>
                        </div>
                        @if($errors->has('address'))
                            <div class="invalid-feedback">
                                <strong>{{ $errors->first('address') }}</strong>
                            </div>
                        @endif
                    </div>

                    <div class="input-group mb-3">
                        <input type="text" name="num" class="form-control {{ $errors->has('num') ? 'is-invalid' : '' }}"
                               value="{{ old('num') }}" placeholder="{{ __('adminlte::adminlte.num') }}"  required autocomplete="off">
                        <div class="input-group-append">
                            <div class="input-group-text">
                                <span class="fas fa-map-marker {{ config('adminlte.classes_auth_icon', '') }}"></span>
                            </div>
                        </div>
                        @if($errors->has('num'))
                            <div class="invalid-feedback">
                                <strong>{{ $errors->first('num') }}</strong>
                            </div>
                        @endif
                    </div>

                    <div class="input-group mb-3">
                        <input type="text" name="district" class="form-control {{ $errors->has('district') ? 'is-invalid' : '' }}"
                               value="{{ old('district') }}" placeholder="{{ __('adminlte::adminlte.district') }}"  required autocomplete="off">
                        <div class="input-group-append">
                            <div class="input-group-text">
                                <span class="fas fa-map-marker {{ config('adminlte.classes_auth_icon', '') }}"></span>
                            </div>
                        </div>
                        @if($errors->has('district'))
                            <div class="invalid-feedback">
                                <strong>{{ $errors->first('district') }}</strong>
                            </div>
                        @endif
                    </div>

                    <div class="form-group">
                        <select name="uf" id="uf" class="form-control select2 {{ $errors->has('uf') ? 'is-invalid' : '' }}" required autocomplete="off">
                            <option value="0" disabled selected hidden>Estado</option>
                            @foreach($uf as $key)
                            <option value="{{$key->uf}}">{{$key->uf}}</option>
                            @endforeach
                        </select>
                        @if($errors->has('uf'))
                            <div class="invalid-feedback">
                                <strong>{{ $errors->first('uf') }}</strong>
                            </div>
                        @endif
                    </div>

                    <div class="form-group">
                        <select name="city" id="city" class="form-control select2 {{ $errors->has('city') ? 'is-invalid' : '' }}" required autocomplete="off">
                            <option value="0" disabled selected hidden>Cidade</option>
                        </select>
                        @if($errors->has('city'))
                            <div class="invalid-feedback">
                                <strong>{{ $errors->first('city') }}</strong>
                            </div>
                        @endif
                    </div>

                    {{-- Email field --}}
                    <div class="input-group mb-3">
                        <input type="email" name="email" class="form-control {{ $errors->has('email') ? 'is-invalid' : '' }}"
                               value="{{ old('email') }}" placeholder="{{ __('adminlte::adminlte.email') }}" required>
                        <div class="input-group-append">
                            <div class="input-group-text">
                                <span class="fas fa-envelope {{ config('adminlte.classes_auth_icon', '') }}"></span>
                            </div>
                        </div>
                        @if($errors->has('email'))
                            <div class="invalid-feedback">
                                <strong>{{ $errors->first('email') }}</strong>
                            </div>
                        @endif
                    </div>

                    {{-- Password field --}}
                    <div class="input-group mb-3">
                        <input type="password" name="password"
                               class="form-control {{ $errors->has('password') ? 'is-invalid' : '' }}"
                               placeholder="{{ __('adminlte::adminlte.password') }}" required autocomplete="off">
                        <div class="input-group-append">
                            <div class="input-group-text">
                                <span class="fas fa-lock {{ config('adminlte.classes_auth_icon', '') }}"></span>
                            </div>
                        </div>
                        @if($errors->has('password'))
                            <div class="invalid-feedback">
                                <strong>{{ $errors->first('password') }}</strong>
                            </div>
                        @endif
                    </div>

                    {{-- Confirm password field --}}
                    <div class="input-group mb-3">
                        <input type="password" name="password_confirmation"
                               class="form-control {{ $errors->has('password_confirmation') ? 'is-invalid' : '' }}"
                               placeholder="{{ __('adminlte::adminlte.retype_password') }}" required autocomplete="off">
                        <div class="input-group-append">
                            <div class="input-group-text">
                                <span class="fas fa-lock {{ config('adminlte.classes_auth_icon', '') }}"></span>
                            </div>
                        </div>
                        @if($errors->has('password_confirmation'))
                            <div class="invalid-feedback">
                                <strong>{{ $errors->first('password_confirmation') }}</strong>
                            </div>
                        @endif
                    </div>

                    {{-- Register button --}}
                    <button type="submit" class="btn btn-block {{ config('adminlte.classes_auth_btn', 'btn-flat btn-primary') }}">
                        <span class="fas fa-user-plus"></span>
                        {{ __('adminlte::adminlte.register') }}
                    </button>

                </form>  
    



    
@stop

@section('auth_footer')
    <p class="my-0">
        <a href="{{ $login_url }}">
            {{ __('adminlte::adminlte.i_already_have_a_membership') }}
        </a>
    </p>
@stop
